@@ -1,8 +1,8 @@
 #' covr: Test coverage for packages
 #'
 #' covr tracks and reports code coverage for your package and (optionally)
-#' upload the results to a coverage service like 'Codecov' <http://codecov.io> or
-#' 'Coveralls' <http://coveralls.io>. Code coverage is a measure of the amount of
+#' upload the results to a coverage service like 'Codecov' <https://codecov.io> or
+#' 'Coveralls' <https://coveralls.io>. Code coverage is a measure of the amount of
 #' code being exercised by a set of tests. It is an indirect measure of test
 #' quality and completeness. This package is compatible with any testing
 #' methodology or framework and tracks coverage of both R code and compiled
@@ -22,8 +22,6 @@
 #' @importFrom utils capture.output getSrcFilename relist str head
 NULL
 
-rex::register_shortcuts("covr")
-
 the <- new.env(parent = emptyenv())
 
 the$replacements <- list()
@@ -78,7 +76,11 @@ function_coverage <- function(fun, code = NULL, env = NULL, enc = parent.frame()
   })
 
   replace(replacement)
-  eval(code, enc)
+
+  withr::with_envvar(c("R_COVR" = "true"),
+    eval(code, enc)
+  )
+
   structure(as.list(.counters), class = "coverage")
 }
 
@@ -114,8 +116,10 @@ file_coverage <- function(
     clear_counters()
   })
 
-  lapply(test_files,
-    sys.source, keep.source = TRUE, envir = env)
+  withr::with_envvar(c("R_COVR" = "true"),
+    lapply(test_files,
+      sys.source, keep.source = TRUE, envir = env)
+  )
 
   coverage <- structure(as.list(.counters), class = "coverage")
 
@@ -169,8 +173,10 @@ environment_coverage <- function(
     clear_counters()
   })
 
-  lapply(test_files,
-    sys.source, keep.source = TRUE, envir = exec_env)
+  withr::with_envvar(c("R_COVR" = "true"),
+    lapply(test_files,
+      sys.source, keep.source = TRUE, envir = exec_env)
+  )
 
   coverage <- structure(as.list(.counters), class = "coverage")
 
@@ -366,7 +372,7 @@ package_coverage <- function(path = ".",
   trace_files <- list.files(path = tmp_lib, pattern = "^covr_trace_[^/]+$", full.names = TRUE)
   coverage <- merge_coverage(trace_files)
   if (!uses_icc()) {
-    res <- run_gcov(pkg$path, quiet = quiet)
+    res <- run_gcov(pkg$path, quiet = quiet, clean = clean)
   } else {
     res <- run_icov(pkg$path, quiet = quiet)
   }
@@ -380,10 +386,19 @@ package_coverage <- function(path = ".",
     attr(coverage, "library") <- tmp_lib
   }
 
-  coverage <- filter_non_package_files(coverage)
+  if (getOption("covr.filter_non_package", TRUE)) {
+    coverage <- filter_non_package_files(coverage)
+  }
 
-  # Exclude both RcppExports to avoid redundant coverage information
-  line_exclusions <- c("src/RcppExports.cpp", "R/RcppExports.R", line_exclusions, parse_covr_ignore())
+  # Exclude generated files from Rcpp and cpp11 to avoid redundant coverage information
+  line_exclusions <- c(
+    "src/RcppExports.cpp",
+    "R/RcppExports.R",
+    "src/cpp11.cpp",
+    "R/cpp11.R",
+    line_exclusions,
+    parse_covr_ignore()
+  )
 
   exclude(coverage,
     line_exclusions = line_exclusions,
@@ -551,3 +566,17 @@ add_hooks <- function(pkg_name, lib, fix_mcexit = FALSE) {
 `[.coverage` <- function(x, ...) {
   structure(NextMethod(), class = "coverage")
 }
+
+#' Determine if code is being run in covr
+#'
+#' covr functions set the environment variable `R_COVR` when they are running.
+#' [in_covr()] returns `TRUE` if this environment variable is set and `FALSE`
+#' otherwise.
+#' @export
+#' @examples
+#' if (require(testthat)) {
+#'   testthat::skip_if(in_covr())
+#' }
+in_covr <- function() {
+  identical(Sys.getenv("R_COVR"), "true")
+}
